#!/bin/bash

# ============================================================================
# Purpose: This script converts the MERSI 1KM and QKM L1B HDF5 files into a 
#     HDF4 files. The CREFL algorithm requires that the reflection calibration
#     coefficients are SDS array attributes. Within the MERSI L1B HDF5 file,
#     the calibration coefficients are in a global attribute. First this script
#     executes a utility program, update_fy3_l1b_calb, to copy the global
#     attribute coefficients to the appropriate dataset arrays. Then the L1B
#     HDF5 files are converted into HDF4 files.
# 
# Input parameters:
#     1. The 1KM MERSI L1B HDF5 file.
#     2. The QKM MERSI L1B HDF5 file.
#     3. The 1KM MERSI L1B HDF4 output file name.
#     4. The QKM MERSI L1B HDF4 output file name.
# 
# Authors: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu
# Date: 07/22/2011 
# ============================================================================

# Convert the MERSI L1B HDF5 files into HDF4 files. Also copy the necessary attributes of 
# the HDF5 files to the HDF4 files.
# Usage: convert_mersi_h5toh4 h5_1km_file h5_qkm_file h4_1km_file_name h4_qkm_file_name
# 
# Author: Willem.Marais@ssec.wisc.edu

# Check for MIPS_HOME environment variable
#if [ -z "$MIPS_HOME" ]; then
#  echo "Environment variable MIPS_HOME is not set"
#  exit 1
#fi

SCRIPT_FILEP_STR=$(readlink -f $0)
BASE_DIRP_STR=$(dirname $SCRIPT_FILEP_STR)

if [ $# -ne 4 ]; then
    echo "Usage:"
    echo $(basename $0)" <MERSI L1B 1km HDF5> <MERSI L1B qkm HDF5> <1km HDF4 file name> <qkm HDF4 file name>" 
    exit 1
fi

h5_1km_file=$1
h5_qkm_file=$2
h4_1km_file=$3
h4_qkm_file=$4

$BASE_DIRP_STR/h5toh4 $h5_1km_file $h4_1km_file
if [ $? -ne 0 ]; then
    echo "(ERROR)[E43] Could not convert 1km MERSI L1B HDF5 file."
    exit 1
fi

$BASE_DIRP_STR/h5toh4 $h5_qkm_file $h4_qkm_file
if [ $? -ne 0 ]; then
    echo "(ERROR)[E44] Could not convert qkm MERSI L1B HDF5 file."
    exit 1
fi

