#!/bin/bash

SCRIPT_FILEP_STR=$(readlink -f $0)
BASE_DIRP_STR=$(dirname $SCRIPT_FILEP_STR)

if [ $# -ne 2 ]; then
    echo "Usage:"
    echo $(basename $0)" <MERSI L1B 1km HDF5> <MERSI L1B qkm HDF5>" 
    exit 1
fi

hdf5_1km_file_str=$1
hdf5_qkm_file_str=$2

# Get the directory where in the HDF5 files are stored
data_dirP_str=$(dirname $hdf5_1km_file_str)

echo "(Step 1/3) Converting HDF5 files to HDF4"
hdf4_1km_file_str=$data_dirP_str"/"$(basename $hdf5_1km_file_str ".HDF")".hdf4"
hdf4_qkm_file_str=$data_dirP_str"/"$(basename $hdf5_qkm_file_str ".HDF")".hdf4"

# Check if the hdf4 files exist
if [ ! -e "$hdf4_1km_file_str" ] || [ ! -e "$hdf4_qkm_file_str" ]; then
    /bin/bash $BASE_DIRP_STR/convert_mersi_h5toh4.bash $hdf5_1km_file_str $hdf5_qkm_file_str \
        $hdf4_1km_file_str $hdf4_qkm_file_str
fi

echo "(Step 2/3) Applying atmospheric correction"
crefl_1km_file_str=$data_dirP_str"/crefl_"$(basename $hdf5_1km_file_str ".HDF")".hdf4"
crefl_qkm_file_str=$data_dirP_str"/crefl_"$(basename $hdf5_qkm_file_str ".HDF")".hdf4"

if [ ! -e "$crefl_1km_file_str" ] || [ ! -e "$crefl_qkm_file_str" ]; then
    /bin/bash $BASE_DIRP_STR/run_mersi_crefl.bash $hdf4_1km_file_str $hdf4_qkm_file_str \
        $crefl_1km_file_str $crefl_qkm_file_str
fi

echo "(Step 3/3) Making granule image"
gran_img_fileP_str=$data_dirP_str"/crefl_img_"$(basename $hdf5_1km_file_str ".HDF")".png"
if [ ! -e "$gran_img_fileP_str" ]; then
    /bin/bash $BASE_DIRP_STR/process_granule_img.bash $gran_img_fileP_str 03_02_01 $crefl_1km_file_str
fi
